@@ -5,7 +5,7 @@ par(fig=c(0,.8,0,1), new=F)
 RainbowColor=rev(redgreen(length(FCOut$PostFC)))
 par(oma=c(0,1,1,0),cex=1.3)
 plot(FCOut$PostFC,FCOut$RealFC,
-log="xy",col=RainbowColor[rank(unlist(EBOut$MeanList)[names(FCOut$PostFC)])], xlab="Posterior FC",
+log="xy",col=RainbowColor[rank(EBOut$Mean)], xlab="Posterior FC",
 ylab="FC",pch=21)
 abline(h=1, v=1, col="gray")
 #legend("topleft",col=c("green","black","red"),legend=c("Low Expression","Median Expression","High Expression"),pch=21)
